@@ -11,7 +11,8 @@ from piperider_cli.adapter import DbtAdapter
 from piperider_cli.assertion_generator import AssertionGenerator
 from piperider_cli.cloud_connector import CloudConnector
 from piperider_cli.compare_report import CompareReport
-from piperider_cli.event.track import TrackCommand
+from piperider_cli.event import UserProfileConfigurator
+from piperider_cli.event.track import TrackCommand, BetaGroup
 from piperider_cli.exitcode import EC_ERR_TEST_FAILED
 from piperider_cli.feedback import Feedback
 from piperider_cli.generate_report import GenerateReport
@@ -232,13 +233,68 @@ def compare_reports(**kwargs):
                        debug=kwargs.get('debug', False))
 
 
-@cli.group('cloud', short_help='Manage PipeRider Cloud')
+@cli.group('config', help='Manage the PipeRider configurations.', cls=BetaGroup)
+def config(**kwargs):
+    pass
+
+
+@config.command(name='list-datasource', short_help='List DataSources in current PipeRider project',
+                cls=TrackCommand,
+                beta=True)
+@add_options(debug_option)
+def list(**kwargs):
+    'List PipeRider current configurations.'
+    Initializer.list()
+
+
+@config.command(name='add-datasource', short_help='Add a DataSource to current PipeRider project.',
+                cls=TrackCommand, beta=True)
+@add_options(debug_option)
+def add(**kwargs):
+    Initializer.add()
+    pass
+
+
+@config.command(name='delete-datasource', short_help='Delete a DataSource from current PipeRider project.',
+                cls=TrackCommand, beta=True)
+@add_options(debug_option)
+def delete(**kwargs):
+    Initializer.list()
+    Initializer.delete()
+    pass
+
+
+@config.command(name='enable-auto-upload', short_help='Enable auto upload to PipeRider Cloud.', cls=TrackCommand,
+                beta=True)
+def enable_auto_upload(**kwargs):
+    CloudConnector.config_auto_upload(True)
+    pass
+
+
+@config.command(name='disable-auto-upload', short_help='Disable auto upload to PipeRider Cloud.', cls=TrackCommand,
+                beta=True)
+def disable_auto_upload(**kwargs):
+    CloudConnector.config_auto_upload(False)
+    pass
+
+
+@config.command(name='enable-user-tracking', short_help='Enable user tracking.', cls=TrackCommand, beta=True)
+def enable_user_tracking(**kwargs):
+    UserProfileConfigurator.update('anonymous_tracking', True, name='user tracking')
+
+
+@config.command(name='disable-user-tracking', short_help='Disable user tracking.', cls=TrackCommand, beta=True)
+def disable_user_tracking(**kwargs):
+    UserProfileConfigurator.update('anonymous_tracking', False, name='user tracking')
+
+
+@cli.group('cloud', short_help='Manage PipeRider Cloud', cls=BetaGroup)
 def cloud(**kwargs):
     # Manage PipeRider Cloud.
     pass
 
 
-@cloud.command(short_help='Upload a report to the PipeRider Cloud.', cls=TrackCommand)
+@cloud.command(short_help='Upload a report to the PipeRider Cloud.', cls=TrackCommand, beta=True)
 @click.option('--run', type=click.Path(exists=True), help='Specify the raw result file.')
 @click.option('--report-dir', default=None, type=click.STRING, help='Use a different report directory.')
 @click.option('--datasource', default=None, type=click.STRING, metavar='DATASOURCE_NAME',
@@ -256,7 +312,7 @@ def upload_report(**kwargs):
     return ret
 
 
-@cloud.command(short_help='Login to PipeRider Cloud.', cls=TrackCommand)
+@cloud.command(short_help='Login to PipeRider Cloud.', cls=TrackCommand, beta=True)
 @click.option('--token', default=None, type=click.STRING, help='Specify the API token.')
 @click.option('--enable-auto-upload', default=None, is_flag=True, help='Enable auto upload.')
 @click.option('--disable-auto-upload', default=None, is_flag=True, help='Disable auto upload.')
@@ -275,7 +331,7 @@ def login(**kwargs):
     return ret
 
 
-@cloud.command(short_help='Logout from PipeRider Cloud.', cls=TrackCommand)
+@cloud.command(short_help='Logout from PipeRider Cloud.', cls=TrackCommand, beta=True)
 @add_options(debug_option)
 def logout(**kwargs):
     ret = CloudConnector.logout()
