@@ -1,4 +1,5 @@
 import json
+import math
 import os
 import re
 import sys
@@ -63,11 +64,18 @@ class RichProfilerEventHandler(ProfilerEventHandler):
         self.table_total = 0
         self.table_completed = 0
 
+        title = "Fetch metadata"
+        text_column = TextColumn("{task.description}", table_column=Column(width=len(title)))
+        bar_column = BarColumn(bar_width=80, pulse_style=Style.from_color(Color.from_rgb(244, 164, 96)))
+        mofn_column = MofNCompleteColumn(table_column=Column(width=5, justify="right"))
+        time_elapsed_column = TimeElapsedColumn()
+        self.progress_metadata = Progress(text_column, bar_column, mofn_column, time_elapsed_column)
+
     def _get_width(self, tables):
         return max([len(x) for x in tables]), len(str(len(tables))) * 2 + 2
 
     def handle_run_start(self, run_result):
-        self.progress.start()
+        self.progress_metadata.start()
 
     def handle_run_progress(self, run_result, total, completed):
         self.table_total = total
@@ -75,19 +83,28 @@ class RichProfilerEventHandler(ProfilerEventHandler):
     def handle_run_end(self, run_result):
         self.progress.stop()
 
-    def handle_fetch_metadata_all_start(self):
-        print("fetching metadata")
+    def handle_fetch_metadata_start(self):
+        task_id = self.progress_metadata.add_task("Fetch metadata", total=None)
+        self.tasks["__metadata__"] = task_id
 
-    def handle_fetch_metadata_table_start(self, table_name):
-        print(f"fetching metadata for table '{table_name}'")
+    def handle_fetch_metadata_progress(self, table_name, total, completed):
+        task_id = self.tasks["__metadata__"]
+        self.progress_metadata.update(task_id, total=total, completed=completed)
+
+    def handle_fetch_metadata_end(self):
+        self.progress_metadata.stop()
+        print("")
+        self.progress.start()
+        pass
 
     def handle_table_start(self, table_result):
         self.table_completed += 1
         table_name = table_result['name']
         padding = ' ' * (len(str(self.table_total)) - len(str(self.table_completed)))
         coft = f'[{padding}{self.table_completed}/{self.table_total}]'
-        task_id = self.progress.add_task(table_name, total=None, **dict(coft=coft))
+        task_id = self.progress.add_task(table_name, total=None, coft=coft)
         self.tasks[table_name] = task_id
+        self.progress.start()
 
     def handle_table_progress(self, table_result, total, completed):
         if completed == 0:
@@ -96,7 +113,10 @@ class RichProfilerEventHandler(ProfilerEventHandler):
             self.progress.update(task_id, total=total)
 
     def handle_table_end(self, table_result):
-        pass
+        self.progress.stop()
+        table_name = table_result['name']
+        task_id = self.tasks[table_name]
+        self.progress.remove_task(task_id)
 
     def handle_column_start(self, table_name, column_result):
         pass
@@ -443,6 +463,8 @@ def _clean_up_profile_null_properties(table_results):
     for t_metric, t_metric_val in table_results.items():
         if t_metric_val is None:
             removed.append(t_metric)
+        elif isinstance(t_metric_val, float) and not math.isfinite(t_metric_val):
+            removed.append(t_metric)
 
     for r in removed:
         del table_results[r]
@@ -452,6 +474,8 @@ def _clean_up_profile_null_properties(table_results):
         for k, v in props.items():
             if v is None:
                 removed.append(dict(col=col_name, key=k))
+            elif isinstance(v, float) and not math.isfinite(v):
+                removed.append(dict(col=col_name, key=k))
 
     for r in removed:
         del table_results['columns'][r['col']][r['key']]
@@ -578,7 +602,8 @@ class Runner():
             console.print(f"[bold red]Error:[/bold red] The credential of '{ds.name}' is not configured.")
             for reason in reasons:
                 console.print(f'    {reason}')
-            console.print("[bold yellow]Hint:[/bold yellow]\n  Please execute command 'piperider init' to move forward.")
+            console.print(
+                "[bold yellow]Hint:[/bold yellow]\n  Please execute command 'piperider init' to move forward.")
             return 1
 
         if not datasource and len(datasource_names) > 1:
@@ -611,10 +636,9 @@ class Runner():
         if dbt_config and not dbt_adapter.is_ready():
             raise dbt_adapter.get_error()
 
-        tables, err_msg = _get_table_list(table, default_schema, dbt_adapter)
-        if err_msg:
-            console.print(f'[bold red]Error:[/bold red] {err_msg}')
-            return 1
+        tables = None
+        if table:
+            tables = [table]
 
         dbt_test_results = None
         dbt_test_results_compatible = None
